pub struct DatagramSummary {
pub frame: u64,
pub tick: u64,
pub ack: u64,
pub stream_tick: u64,
pub parts: u64,
pub updated: Vec<EntityId>,
pub skipped: usize,
}Expand description
What one datagram did.
Fields
frame: u64tick: u64ack: u64stream_tick: u64The tick of the last stream frame the server had sent by tick.
parts: u64Datagrams the server sent for tick.
updated: Vec<EntityId>Entities it updated.
skipped: usizeUpdates it skipped: an unknown entity, another spawn, an older datagram than the entity’s last, or a precision the table is not in.