LEB128 varints and zigzag signed integers.
Functions
- len_u64
- Bytes
write_u64uses forv. - read_
i64 - read_
u64 - Read an unsigned LEB128 varint and advance
bytespast it. None when it is truncated or longer than 10 bytes. - write_
i64 - Append a signed integer as a zigzag varint (small magnitudes are short).
- write_
u64 - Append
vas an unsigned LEB128 varint (1 to 10 bytes).